#
# Configuration file for using the libIDL library in GNOME applications
#
LIBIDL_INCLUDEDIR="-I/work/mozilla/sysbin/dist/lib/glib/include -I/work/mozilla/sysbin/dist/include -I/work/mozilla/sysbin/dist/include"
LIBIDL_LIBDIR="-L/work/mozilla/sysbin/dist/lib"
LIBIDL_LIBS="-lIDL -L/work/mozilla/sysbin/dist/lib -lglib"
